@@ -27,8 +27,8 @@ class Note(Cached):
     def from_i(cls, i: int) -> Note:
         return cls(config.chromatic_notes[i % 12])
 
-    def short_repr(self): return self.name
-    def __repr__(self): return f'Note(name={self.name})'
+    def __repr__(self) -> str:
+        return f'Note(name={self.name})'
 
     def __eq__(self, other: object) -> bool:
         if isinstance(other, str):
@@ -46,16 +46,19 @@ class Note(Cached):
         else:
             return NotImplemented
 
-    def __hash__(self): return hash(self.name)
+    def __hash__(self) -> int:
+        return hash(self.name)
 
     def __add__(self, other: int) -> Note:
         return Note.from_i(self.i + other)
 
     @overload
-    def __sub__(self, other: Note) -> int: ...
+    def __sub__(self, other: Note) -> int:
+        ...
 
     @overload
-    def __sub__(self, other: int) -> Note: ...
+    def __sub__(self, other: int) -> Note:
+        ...
 
     def __sub__(self, other: Note | int) -> int | Note:
         """
@@ -71,7 +74,7 @@ class Note(Cached):
         elif isinstance(other, int):
             return self + (-other)
 
-    def __getnewargs__(self):
+    def __getnewargs__(self) -> tuple[str]:
         return self.name,
 
 
@@ -85,7 +88,6 @@ class SpecificNote(Cached):
             abstract = Note(abstract)
         self.abstract = abstract
         self.is_black = abstract.is_black
-        # super().__init__(abstract.name)
         self.octave = octave
         self.i: int = octave * 12 + self.abstract.i  # this is also midi_code
         self._key = self.abstract, self.octave
@@ -104,7 +106,8 @@ class SpecificNote(Cached):
         await asyncio.sleep(seconds)
         player.send_message('note_off', note=self.i, channel=0)
 
-    def __repr__(self): return f'{self.abstract.name}{self.octave}'
+    def __repr__(self) -> str:
+        return f'{self.abstract.name}{self.octave}'
 
     def __eq__(self, other: object) -> bool:
         if isinstance(other, SpecificNote):
@@ -114,7 +117,8 @@ class SpecificNote(Cached):
         else:
             return NotImplemented
 
-    def __hash__(self): return hash(self._key)
+    def __hash__(self) -> int:
+        return hash(self._key)
 
     def __lt__(self, other: object) -> bool:
         if not isinstance(other, SpecificNote):
@@ -122,10 +126,12 @@ class SpecificNote(Cached):
         return self.i < other.i
 
     @overload
-    def __sub__(self, other: SpecificNote) -> int: ...
+    def __sub__(self, other: SpecificNote) -> int:
+        ...
 
     @overload
-    def __sub__(self, other: int) -> SpecificNote: ...
+    def __sub__(self, other: int) -> SpecificNote:
+        ...
 
     # @functools.cache
     def __sub__(self, other: SpecificNote | int) -> int | SpecificNote:
@@ -133,7 +139,8 @@ class SpecificNote(Cached):
             return self.i - other.i
         elif isinstance(other, int):  # subtract semitones
             return self + (-other)
-        else: raise TypeError(f'SpecificNote.__sub__ supports only SpecificNote | int, got {type(other)}')
+        else:
+            raise TypeError(f'SpecificNote.__sub__ supports only SpecificNote | int, got {type(other)}')
 
     def __add__(self, other: int) -> SpecificNote:
         """C + 7 = G"""
@@ -143,7 +150,7 @@ class SpecificNote(Cached):
     def to_abstract(notes: Iterable[SpecificNote]) -> frozenset[Note]:
         return frozenset(note.abstract for note in notes)
 
-    def __getnewargs__(self):
+    def __getnewargs__(self) -> tuple[Note, int]:
         return self.abstract, self.octave
 
 
