@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import random
+from collections.abc import Iterator
 from typing import TypeVar
 from typing import no_type_check
 from typing import overload
@@ -61,9 +62,9 @@ class NoteSet(Cached, Card):
 
     def __init__(
         self,
-        notes: frozenset[str | Note],
+        notes: frozenset[Note],
         *,
-        root: str | Note | None = None,
+        root: Note | None = None,
     ):
         if not isinstance(notes, frozenset):
             raise TypeError(f'expected frozenset, got {type(notes)}')
@@ -71,7 +72,7 @@ class NoteSet(Cached, Card):
         if len(notes) == 0:
             self.notes = frozenset()
         elif typeguards.is_frozenset_of_str(notes):
-            self.notes = frozenset(Note(note) for note in notes)
+            raise TypeError('expected frozenset of Note, got frozenset of str')
         elif typeguards.is_frozenset_of_note(notes):
             self.notes = notes
         else:
@@ -83,17 +84,12 @@ class NoteSet(Cached, Card):
             self.root = root
             self.notes_ascending = self.notes_octave_fit
             self.intervals_ascending = ()
+        elif not isinstance(root, Note):
+            raise TypeError('root type should be Note | None')
+        elif root not in self.notes:
+            raise KeyError('root should be one of notes')
         else:
-            if root not in self.notes:
-                raise KeyError('root should be one of notes')
-
-            if isinstance(root, Note):
-                self.root = root
-            elif isinstance(root, str):
-                self.root = Note(root)
-            else:
-                raise TypeError('root type should be str | Note | None')
-
+            self.root = root
             root_i = self.notes_octave_fit.index(self.root)
             self.notes_ascending = self.notes_octave_fit[root_i:] + self.notes_octave_fit[:root_i]
             self.intervals_ascending = tuple(note - self.root for note in self.notes_ascending)
@@ -106,7 +102,8 @@ class NoteSet(Cached, Card):
         self.note_i = {note: i for i, note in enumerate(self.notes_ascending)}
 
     @property
-    def rootless(self): return NoteSet(self.notes)
+    def rootless(self) -> NoteSet:
+        return NoteSet(self.notes)
 
     def transpose_to(self, note: Note) -> NoteSet:
         if self.root is None:
@@ -132,39 +129,46 @@ class NoteSet(Cached, Card):
     def random(cls: type[Self], n_notes: int | None = None) -> Self:
         if n_notes is None:
             n_notes = random.randint(2, 5)
-        notes = frozenset(random.sample(config.chromatic_notes, n_notes))
+        notes = frozenset(map(Note, random.sample(config.chromatic_notes, n_notes)))
         return cls(notes)
 
     @classmethod
     def from_str(cls: type[Self], string: str) -> Self:
         notes, _, root_ = string.partition('/')
-        root = Note(root_) if root_ else None
-        return cls(frozenset(Note(note) for note in notes), root=root)
+        kw = {'root': Note(root_)} if root_ else {}
+        return cls(frozenset(Note(note) for note in notes), **kw)
 
     @overload
-    def add_note(self, note: str, steps: int) -> Note | SpecificNote: ...
+    def add_note(self, note: str, steps: int) -> Note | SpecificNote:
+        ...
+
     @overload
-    def add_note(self, note: SpecificNote, steps: int) -> SpecificNote: ...
+    def add_note(self, note: SpecificNote, steps: int) -> SpecificNote:
+        ...
+
     @overload
-    def add_note(self, note: Note, steps: int) -> Note: ...
+    def add_note(self, note: Note, steps: int) -> Note:
+        ...
 
     def add_note(self, note: AnyNote, steps: int) -> Note | SpecificNote:
         if len(self) == 0:
             raise NotImplementedError('cannot add notes using empty noteset')
         notes = self.notes_ascending
-        if type(note) is str:
+        if isinstance(note, str):
             note = str_to_note(note)
-        if type(note) is Note:
+        if isinstance(note, Note):
             return notes[(notes.index(note) + steps) % len(notes)]
-        elif type(note) is SpecificNote:
+        elif isinstance(note, SpecificNote):
             octaves, i = divmod(self.notes_octave_fit.index(note.abstract) + steps, len(self.notes))
             return SpecificNote(self.notes_octave_fit[i], octave=note.octave + octaves)
         else:
             raise TypeError
 
     def subtract(self, left: AnyNote, right: AnyNote) -> int:
-        if type(left) is str: left = str_to_note(left)
-        if type(right) is str: right = str_to_note(right)
+        if isinstance(left, str):
+            left = str_to_note(left)
+        if isinstance(right, str):
+            right = str_to_note(right)
 
         if type(left) is type(right) is Note:
             return (self.note_i[left] - self.note_i[right]) % len(self)
@@ -173,20 +177,43 @@ class NoteSet(Cached, Card):
         else:
             raise TypeError('left and right should be either Note or SpecificNote (or str representation)')
 
-    def __eq__(self, other): return self.key == other.key
-    def __hash__(self): return hash(self.key)
-    def __len__(self): return len(self.notes)
-    def __getitem__(self, item): return self.notes_ascending[item]
-    def __iter__(self): return iter(self.notes_ascending)
-    def __contains__(self, item: str | Note) -> bool: return item in self.notes
-    def __le__(self, other): return self.notes <= other
-    def __ge__(self, other): return other <= self.notes
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, NoteSet):
+            return NotImplemented
+        return self.key == other.key
 
-    def __repr__(self):
-        _ = ''.join(note.name for note in self)
+    def __hash__(self) -> int:
+        return hash(self.key)
+
+    def __len__(self) -> int:
+        return len(self.notes)
+
+    def __getitem__(self, item: int) -> Note:
+        return self.notes_ascending[item]
+
+    def __iter__(self) -> Iterator[Note]:
+        return iter(self.notes_ascending)
+
+    def __contains__(self, item: object) -> bool:
+        if not isinstance(item, Note):
+            return NotImplemented
+        return item in self.notes
+
+    def __le__(self, other: object) -> bool:
+        if not isinstance(other, NoteSet):
+            return NotImplemented
+        return self.notes <= other.notes
+
+    def __ge__(self, other: object) -> bool:
+        if not isinstance(other, NoteSet):
+            return NotImplemented
+        return other.notes <= self.notes
+
+    def __repr__(self) -> str:
+        x = ''.join(note.name for note in self)
         if self.root is not None:
-            _ += f'/{self.root.name}'
-        return _
+            return f'{x}/{self.root.name}'
+        return x
 
     def to_piano_image(self) -> str:
         from musictool.piano import Piano  # hack to fix circular import
@@ -198,14 +225,16 @@ class NoteSet(Cached, Card):
         title: str | None = None,
         subtitle: str | None = None,
         header_href: str | None = None,
+        background_color: str | None = None,
     ) -> str:
         return self.repr_card(
             html_classes=html_classes,
             title=title or repr(self),
             subtitle=subtitle,
             header_href=header_href,
+            background_color=background_color,
             piano_html=self.to_piano_image(),
         )
 
-    def __getnewargs_ex__(self):
+    def __getnewargs_ex__(self) -> tuple[tuple[frozenset[Note]], dict[str, Note | None]]:
         return (self.notes,), {'root': self.root}
